@@ -50,6 +50,9 @@ class TracPost(Plugin):
 	return action_list
 
 def start(request, group_id):
+	print "Got to start - URL Works"
 	tp = Tracpost()
+	print "Can Init Tracpost"
 	response = tp.send_message(group_id)
+	print "Ticket Got Sent!"
 	return response
